###########################################################################
#
# win32 makefile -- src/recpt
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2008  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDL_DIR = ..\..
INDEXERS_DIR = $(GSDL_DIR)\indexers
COLSERVR_DIR = $(GSDL_DIR)\src\colservr
PROTOCOL_DIR = $(GSDL_DIR)\src\protocol
Z3950_DIR = $(GSDL_DIR)\src\z3950


GSDL_VC4 = 0
LOCAL_LIBRARY = 0
USE_Z3950 = 0
DLL = 0
DLLDEBUG = 0
ENABLE_ACCENTFOLD = 1

STLPATH = "$(GSDL_DIR)\packages\windows\stlport\stlport"


!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(DLL)
CPPFLAGS = $(CPPFLAGS) -MD
!ELSE
!IF ($(DLLDEBUG))
CPPFLAGS = $(CPPFLAGS) -MDd
!ENDIF
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
ACCENTFOLD_LIBS = "$(INDEXERS_DIR)\packages\unac\libunac.lib" "$(INDEXERS_DIR)\packages\unac\iconv.lib"
!ELSE
ACCENTFOLD_LIBS = 
!ENDIF

!IF $(USE_Z3950)
DEFS = $(DEFS) -DUSE_Z3950
Z3950EXEC = z3950server.exe
Z3950OBJS = z3950proto.obj z3950proxy.obj  yaz_zclient.obj zparse.tab.obj zparse.yy.obj 
Z_CLIENTOBJS = "$(YAZDIR)\win\obj\tabcomplete.obj"
Z_LIBYAZ = "$(YAZDIR)\lib\yaz.lib"
LDFLAGS = $(LDFLAGS) /link /NOD:msvcrt.lib
!ELSE
Z3950EXEC = 
Z3950OBJS =
Z_CLIENTOBJS =
Z_LIBYAZ =
!ENDIF


AR = lib
CC = cl
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -DPARADOCNUM -D_LITTLE_ENDIAN -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE -DGSDL_NOCACHE
INCLUDES = -I. -I"$(GSDL_DIR)" -I"$(GSDL_DIR)\lib" -I"$(COLSERVR_DIR)" -I"$(PROTOCOL_DIR)" \
	-I"$(INDEXERS_DIR)\mg" -I"$(INDEXERS_DIR)\mg\lib" -I"$(INDEXERS_DIR)\mgpp\text" \
	-I"$(GSDL_DIR)\packages\windows\crypt\crypt" -I"$(GSDL_DIR)\packages\windows\expat\expat" \
	-I"$(GSDL_DIR)\packages\windows\gdbm\gdbm" $(Z3950_INCLUDES)
LDFLAGS = 
LIBS = "$(GSDL_DIR)\packages\windows\crypt\crypt\crypt.lib" "$(GSDL_DIR)\packages\windows\expat\expat\libexpat.lib" \
        "$(GSDL_DIR)\packages\windows\gdbm\gdbm\gdbm.lib" $(ACCENTFOLD_LIBS) $(Z3950_LIBS)

!IF $(GSDL_VC4)
DEFS = $(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I$(STLPATH)
!ENDIF
!IF $(LOCAL_LIBRARY)
DEFS = $(DEFS) -DGSDL_LOCAL_LIBRARY
!ENDIF


COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo -Fe"$@" 


.SUFFIXES:
.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 


SOURCES = \
	action.cpp \
	argdb.cpp \
	authenaction.cpp \
	browseaction.cpp \
	browseactiontools.cpp \
	browserclass.cpp \
	browsetoolsclass.cpp \
	cgiargs.cpp \
	cgiutils.cpp \
	cgiwrapper.cpp \
	collectoraction.cpp \
	configaction.cpp \
        converter.cpp \
	datelistbrowserclass.cpp \
	depositoraction.cpp \
	documentaction.cpp \
	extlinkaction.cpp \
	formattools.cpp \
	gtiaction.cpp \
	highlighttext.cpp \
	historydb.cpp \
	hlistbrowserclass.cpp \
	htmlbrowserclass.cpp \
	htmlutils.cpp \
	invbrowserclass.cpp \
	librarymain.cpp \
	maincfg.cpp \
	pageaction.cpp \
	pagedbrowserclass.cpp \
	phindaction.cpp \
	phindbrowserclass.cpp \
	pingaction.cpp \
	queryaction.cpp \
	querytools.cpp \
	receptionist.cpp \
	recptprototools.cpp \
	statusaction.cpp \
	summarise.cpp \
	tipaction.cpp \
	userdb.cpp \
	usersaction.cpp \
	vlistbrowserclass.cpp \
	wizardaction.cpp

OBJECTS = \
	action.obj \
	argdb.obj \
	authenaction.obj \
	browseaction.obj \
	browseactiontools.obj \
	browserclass.obj \
	browsetoolsclass.obj \
	cgiargs.obj \
	cgiutils.obj \
	cgiwrapper.obj \
	collectoraction.obj \
	configaction.obj \
        converter.obj \
	datelistbrowserclass.obj \
	depositoraction.obj \
	documentaction.obj \
	extlinkaction.obj \
	formattools.obj \
	gtiaction.obj \
	highlighttext.obj \
	historydb.obj \
	hlistbrowserclass.obj \
	htmlbrowserclass.obj \
	htmlutils.obj \
	invbrowserclass.obj \
	librarymain.obj \
	maincfg.obj \
	pageaction.obj \
	pagedbrowserclass.obj \
	phindaction.obj \
	phindbrowserclass.obj \
	pingaction.obj \
	queryaction.obj \
	querytools.obj \
	receptionist.obj \
	recptprototools.obj \
	statusaction.obj \
	summarise.obj \
	tipaction.obj \
	userdb.obj \
	usersaction.obj \
	vlistbrowserclass.obj \
	wizardaction.obj

GSDL_LIBS = \
	"$(PROTOCOL_DIR)\gsdlprotocol.lib" \
	"$(COLSERVR_DIR)\gsdlcolservr.lib" \
	"$(GSDL_DIR)\lib\gsdllib.lib" \
	"$(INDEXERS_DIR)\mg\src\text\libmgtext.lib" \
	"$(INDEXERS_DIR)\mg\lib\libmglib.lib" \
	"$(INDEXERS_DIR)\mgpp\text\libmgpptext.lib" \
	"$(INDEXERS_DIR)\mgpp\lib\libmgpplib.lib"

EXECUTABLE_OBJECTS = \
	$(OBJECTS) \
	$(GSDL_LIBS)

EXECUTABLE = library.exe


library.exe: $(EXECUTABLE_OBJECTS)
	$(LINK) $(EXECUTABLE_OBJECTS) $(LIBS)


LIBRARY = gsdlrecpt.lib

gsdlrecpt.lib: $(OBJECTS) 
	if EXIST gsdlrecpt.lib del gsdlrecpt.lib
	$(AR) -nologo /out:gsdlrecpt.lib $(OBJECTS)


!IF $(LOCAL_LIBRARY)
all: $(LIBRARY)
!ELSE
all: $(EXECUTABLE)
!ENDIF

!IF $(LOCAL_LIBRARY)
install: $(LIBRARY)
!ELSE
install: $(EXECUTABLE)
	copy library.exe "$(GSDL_DIR)\cgi-bin"
!ENDIF

clean:
	del *.obj
	del library.exe


# Always recompile configaction and statusaction in case GSDL_LOCAL_LIBRARY has changed
statusaction.obj: FORCE
configaction.obj: FORCE

FORCE:
